@@ -33,7 +33,7 @@ def get_user_pk_by_username(username):
 							database='ebdb',
 							user='admin',
 							password=BD_PASS)
-		query = f"SELECT id FROM automlapp_user WHERE username = {username};"
+		query = f"SELECT id FROM automlapp_user WHERE username = '{username}';"
 		cursor = db.cursor()
 		cursor.execute(query)
 		response = cursor.fetchone()
@@ -70,7 +70,8 @@ def get_project_pk_by_user_pk_project_name(user_pk, project_name):
 							database='ebdb',
 							user='admin',
 							password=BD_PASS)
-		query = "SELECT id FROM automlapp_project WHERE user_id = " + str(user_pk) + " AND proj_name = \"" + project_name + "\";"
+		query = f'SELECT id FROM automlapp_project WHERE user_id = {user_pk} AND proj_name = "{project_name}";'
+		# query = "SELECT id FROM automlapp_project WHERE user_id = " + str(user_pk) + " AND proj_name = \"" + project_name + "\";"
 		cursor = db.cursor()
 		cursor.execute(query)
 		response = cursor.fetchone()
@@ -691,3 +692,22 @@ def get_project_port(project_pk):
 	finally:
 		db.close()
 	return port
+
+def get_cluster_name_of_project(project_pk):
+	cluster_name = ""
+	try:
+		db = mysql.connect(host=BD_HOST,
+							database='ebdb',
+							user='admin',
+							password=BD_PASS)
+		query = f"SELECT cluster_name FROM automlapp_project WHERE id = {project_pk};"
+		cursor = db.cursor()
+		cursor.execute(query)
+		response = cursor.fetchone()
+		if response:
+			cluster_name = str(response[0])
+	except Exception as e:
+		print("v : ERROR : " + str(e))
+	finally:
+		db.close()
+	return cluster_name
